from .base import (
    CFObject,
    CloudFormation,
)
from .conditions import Condition
from .mappings import Mapping
from .metadata import Metadata
from .outputs import Output
from .parameters import Parameter
from .resources import Resource
from .rules import Rule
from .transform import Transformation

from .templates import templates
templates = tuple(templates.values())
